@@ -727,7 +727,8 @@ def export(docs, index, mirrors=None, update=False,
     else:
         if isinstance(index, pymongo.collection.Collection):
             logger.info("Using optimized export function export_pymongo().")
-            return export_pymongo(docs, index, mirrors, num_tries, timeout, **kwargs)
+            return export_pymongo(docs=docs, index=index, mirrors=mirrors,
+                                  update=update, num_tries=num_tries, timeout=timeout, **kwargs)
     ids = defaultdict(list)
     for doc in docs:
         _id, _ = export_one(doc, index, mirrors, num_tries, timeout, **kwargs)
@@ -769,7 +770,7 @@ def _export_pymongo(docs, operations, index, mirrors, num_tries, timeout):
         raise errors.ExportError()
 
 
-def export_pymongo(docs, index, mirrors=None, num_tries=3, timeout=60, chunksize=100):
+def export_pymongo(docs, index, mirrors=None, update=False, num_tries=3, timeout=60, chunksize=100):
     """Optimized :py:func:`~.export` function for pymongo index collections.
 
     The behavior of this function is rougly equivalent to:
@@ -799,8 +800,13 @@ def export_pymongo(docs, index, mirrors=None, num_tries=3, timeout=60, chunksize
     logger.info("Exporting to pymongo database collection index '{}'.".format(index))
     chunk = []
     operations = []
+    ids = defaultdict(list)
     for doc in docs:
         f = {'_id': doc['_id']}
+        if update:
+            root = doc.get('root')
+            if root is not None:
+                ids[root].append(doc['_id'])
         chunk.append(doc)
         operations.append(pymongo.ReplaceOne(f, doc, upsert=True))
         if len(chunk) >= chunksize:
@@ -811,6 +817,19 @@ def export_pymongo(docs, index, mirrors=None, num_tries=3, timeout=60, chunksize
     if len(operations):
         logger.debug("Pushing final chunk.")
         _export_pymongo(chunk, operations, index, mirrors, num_tries, timeout)
+    if update:
+        if ids:
+            stale = set()
+            for root in ids:
+                docs_ = index.find({'root': root})
+                all_ = {doc['_id'] for doc in docs_}
+                stale.update(all_.difference(ids[root]))
+            logger.info("Removing {} stale documents.".format(len(stale)))
+            for _id in set(stale):
+                index.delete_one(dict(_id=_id))
+        else:
+            raise errors.ExportError(
+                "The exported docs sequence is empty! Unable to update!")
 
 
 def index_files(root='.', formats=None, depth=0):
