@@ -15,6 +15,8 @@ class SyncedAttrDict(_SyncedDict):
         ad = SyncedAttrDict(nested_dict)
         assert ad.a.b == 0
     """
+    _PROTECTED_KEYS = ('_data', '_suspend_sync_', '_load', '_save')
+
     def __getattr__(self, name):
         try:
             return super(SyncedAttrDict, self).__getattribute__(name)
@@ -32,7 +34,7 @@ class SyncedAttrDict(_SyncedDict):
         except AttributeError:
             super(SyncedAttrDict, self).__setattr__(key, value)
         else:
-            if key.startswith('__') or key in ('_data', '_suspend_sync_', '_load', '_save'):
+            if key.startswith('__') or key in self.__getattribute__('_PROTECTED_KEYS'):
                 super(SyncedAttrDict, self).__setattr__(key, value)
             else:
                 self.__setitem__(key, value)
